package cs202.account;

import java.util.Calendar;

public class SavingsAccount extends Account {

    // date of the last withdraw
    private Calendar lastWithdraw;

    // num of withdraws made this month
    private int      numOfWithdraws;

    public SavingsAccount( String owner )
    {
        this( owner, 0.0 );
    }

    public SavingsAccount( String owner, double balance )
    {
        super( owner, balance );
        lastWithdraw = null;
        numOfWithdraws = 0;
    }

    private boolean isLastWithdrawInThisMonth()
    {
        if( lastWithdraw == null ) return false;

        Calendar cal = Calendar.getInstance();
        int thisYear = cal.get( Calendar.YEAR );
        int thisMonth = cal.get( Calendar.MONTH );

        return thisYear == lastWithdraw.get( Calendar.YEAR )
                && thisMonth == lastWithdraw.get( Calendar.MONTH );

    }

    /**
     * overrides the withdraw method in the superclass. returns the actual
     * amount withdrawn.
     */
    public double withdraw( double amount )
    {
        if( isLastWithdrawInThisMonth() )
        {
            if( numOfWithdraws == 2 )
                return 0;
            else
            {
                lastWithdraw = Calendar.getInstance();
                ++numOfWithdraws;
                return super.withdraw( amount );
            }
        }
        else
        {
            lastWithdraw = Calendar.getInstance();
            numOfWithdraws = 1;
            return super.withdraw( amount );
        }
    }

    // testing
    public static void main( String args[] )
    {
        SavingsAccount s = new SavingsAccount( "cysun" );
        s.deposit( 100.0 );
        System.out.println( s.withdraw( 10.0 ) );
        System.out.println( s.withdraw( 20.0 ) );
        System.out.println( s.withdraw( 30.0 ) );
    }

} // end of class SavingsAccount
